Pcm class

Inheritance

Constructors

Pcm(AudioFormat audioFormat, {required Depth? depth, required Endianness? endianness, required NbChannels? nbChannels, required int? sampleRate})
Pcm.aiff()
Pcm.wav()

Properties

audioFormat ↔ AudioFormat?
getter/setter pairinherited
deprecatedCodec ↔ Codec
getter/setter pairinherited
depth ↔ Depth?
getter/setter pair
endianness ↔ Endianness?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nbChannels ↔ NbChannels?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate ↔ int?
getter/setter pair

Methods

nbrChannels() → int
nDepth() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited