TauCodec class abstract

A TauCodec is an object specifying the codec itself and the file format

Implementers

Constructors

TauCodec()

Properties

audioFormat ↔ AudioFormat?
getter/setter pair
deprecatedCodec ↔ Codec
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited