InputFileNode class

An InputFile is a possible source for a Player playback

Inheritance

Constructors

InputFileNode(String uri, {TauCodec? codec, TauTrack? track})

Properties

codec ↔ TauCodec
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
track ↔ TauTrack
getter/setter pairinherited
uri ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toWave() → Future<InputFileNode>

Operators

operator ==(Object other) → bool
The equality operator.
inherited